What is Giotto?
===============

Giotto is a python web framework. It encourages a functional style where model, view and controller code is strongly decoupled.

Key Features of Giotto include:

* "Your code calls the framework" style over "Framework calls your code" style
* Generic views, generic models and multiple pluggable controllers
* Functional CRUD patterns that do away with the need for django-style form objects.
* Automatic URL routing
* Extensible functionality
* Built in cache (supports Redis and Memcache, and an API for supporting any other engines)
* SQLAlchemy for database persistence
* Jinja2 for HTML templates (with an API for extending for other template engines)

Links:

* To discuss Giotto, please visit the Google Group_
* Read Giotto's documentation_.
* Check out giottoblog_, a full featured blog application written with the Giotto framework.

.. _Group: https://groups.google.com/forum/#!forum/giotto-framework/
.. _giottoblog: https://github.com/priestc/giottoblog/
.. _documentation: http://giotto.readthedocs.org/en/latest/index.html